==> abi-0.7.10.tar.gz: abi-0.7.10/src/wp/ap/xp/ap_Menu_LabelSet_da-DK.h <==
/* AbiWord
 * Copyright (C) 1998-2000 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

// Danish translations provided by Martin Willemoes Hansen <mwh@stampede.org>
//                             , Birger Langkjer <birger.langkjer@image.dk>
//                             and Rasmus Toftdahl Olesen <rto@post.tele.dk>

/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

// We use the Win32 '&' character to denote a keyboard accelerator on a menu item.
// If your platform doesn't have a way to do accelerators or uses a different
// character, remove or change the '&' in your menu constructor code.

// If the third argument is UT_TRUE, then this is the fall-back for
// this language (named in the first argument).

BeginSet(da,DK,UT_TRUE)

	MenuLabel(AP_MENU_ID__BOGUS1__,			NULL,				NULL)

	//       (id,                       	szLabel,           	szStatusMsg)

	MenuLabel(AP_MENU_ID_FILE,				"&Filer",			NULL)
	MenuLabel(AP_MENU_ID_FILE_NEW,			"&Ny", 				"Nyt dokument")	
	MenuLabel(AP_MENU_ID_FILE_OPEN,			"&bn",				"bn et eksisterende dokument")
	MenuLabel(AP_MENU_ID_FILE_CLOSE,		"&Luk", 			"Luk dokumentet")
	MenuLabel(AP_MENU_ID_FILE_SAVE,			"&Gem", 			"Gem dokumentet")
	MenuLabel(AP_MENU_ID_FILE_SAVEAS,		"Gem &som", 			"Gem dokumentet under et andet navn")
	MenuLabel(AP_MENU_ID_FILE_PAGESETUP,		"&Sideopstning",		"ndr sideopstning")
	MenuLabel(AP_MENU_ID_FILE_PRINT,		"&Udskriv",			"Udskriv hele dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_1,		"&1 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_2,		"&2 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_3,		"&3 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_4,		"&4 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_5,		"&5 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_6,		"&6 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_7,		"&7 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_8,		"&8 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_9,		"&9 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_EXIT,			"&Afslut", 			"Luk alle vinduer og afslut programmet")

	MenuLabel(AP_MENU_ID_EDIT,				"&Redigr",			NULL)
	MenuLabel(AP_MENU_ID_EDIT_UNDO,			"F&ortryd",			"Fortryd ndring")
	MenuLabel(AP_MENU_ID_EDIT_REDO,			"&Gentag",			"Gentag sidste fortrydte ndring")
	MenuLabel(AP_MENU_ID_EDIT_CUT,			"K&lip",			"Udklip det markerede og put det i udklipsholderen")
    MenuLabel(AP_MENU_ID_EDIT_COPY,			"&Kopir",			"Kopir det markerede og put det i udklipsholderen")
	MenuLabel(AP_MENU_ID_EDIT_PASTE,		"&Indst",			"Indst udklipsholderens indhold")
	MenuLabel(AP_MENU_ID_EDIT_CLEAR,		"&Ryd",				"Fjern det markerede")
	MenuLabel(AP_MENU_ID_EDIT_SELECTALL,		"&Markr alt",		"Markr hele dokumentet")
	MenuLabel(AP_MENU_ID_EDIT_FIND,			"&Sg",				"Sg efter en angivet tekst")
	MenuLabel(AP_MENU_ID_EDIT_REPLACE,		"&Erstat",			"Erstat en angivet tekst med en anden tekst")
	MenuLabel(AP_MENU_ID_EDIT_GOTO,			"G &til",			"Flyt markren til en angivet placering")
	
	MenuLabel(AP_MENU_ID_VIEW,				"&Vis",				NULL)
	MenuLabel(AP_MENU_ID_VIEW_TOOLBARS,		"&Vrktjslinier",				NULL)
	MenuLabel(AP_MENU_ID_VIEW_TB_STD,		"&Standard",			"Vis eller skjul standard vrktjslinjen")
	MenuLabel(AP_MENU_ID_VIEW_TB_FORMAT,		"&Formatering",			"Vis eller skjul formatering vrktjslinjen")
	MenuLabel(AP_MENU_ID_VIEW_RULER,		"&Lineal",			"Vis eller skjul linealerne")
	MenuLabel(AP_MENU_ID_VIEW_STATUSBAR,		"S&tatuslinie",			"Vis eller skjul statuslinjen")
	MenuLabel(AP_MENU_ID_VIEW_SHOWPARA,		"Vis &afsnit",		"Vis tegn der ikke skal udskrives")
	MenuLabel(AP_MENU_ID_VIEW_HEADFOOT,		"Side&hoved og sidefod",	"Redigr tekst i toppen eller i bunden af hver side")
	MenuLabel(AP_MENU_ID_VIEW_ZOOM,			"&Zoom",			"Formindsk eller forstr dokumentet p skrmen")

	MenuLabel(AP_MENU_ID_INSERT,				"&Indst",			NULL)
	MenuLabel(AP_MENU_ID_INSERT_BREAK,		"&Skift",			"Indst et side-, rkke- eller sektionsskift")
	MenuLabel(AP_MENU_ID_INSERT_PAGENO,		"Side&tal",			"Indst et automatisk opdateret sidetal")
	MenuLabel(AP_MENU_ID_INSERT_DATETIME,		"&Dato og klokkeslet",		"Indst datoen og/eller klokkeslt")
	MenuLabel(AP_MENU_ID_INSERT_FIELD,		"&Felt",			"Indst et kalkuleret felt")
	MenuLabel(AP_MENU_ID_INSERT_SYMBOL,		"Sy&mbol",			"Indst et symbol eller andre specielle tegn")
	MenuLabel(AP_MENU_ID_INSERT_GRAPHIC,		"&Billede",			"Indst et billede fra en fil")

	MenuLabel(AP_MENU_ID_FORMAT,				"F&ormatr",			NULL)
	MenuLabel(AP_MENU_ID_FMT_FONT,			"&Skrifttype",			"ndr skrifttype for den markerede tekst")
	MenuLabel(AP_MENU_ID_FMT_PARAGRAPH,		"&Afsnit",			"ndr formatet for det markerede afsnit")
	MenuLabel(AP_MENU_ID_FMT_BULLETS,		"&Punktopstilling",		"Tilfj eller ndr punktopstillingen for det markerede afsnit")
	MenuLabel(AP_MENU_ID_FMT_BORDERS,		"&Rammer og skygge",		"Tilfj rammer og skygge til den markerede tekst")
	MenuLabel(AP_MENU_ID_FMT_COLUMNS,		"Ko&lonner",			"ndr antallet af kolonner")
	MenuLabel(AP_MENU_ID_FMT_STYLE,			"St&il",			"Angiv eller tilfj stil for den markerede tekst")
	MenuLabel(AP_MENU_ID_FMT_TABS,			"&Tabulatorer",			"St tabulatorstop")
	MenuLabel(AP_MENU_ID_FMT_BOLD,			"&Fed",				"Gr den markerede tekst fed")
	MenuLabel(AP_MENU_ID_FMT_ITALIC,		"&Kursiv",			"Gr den markerede tekst kursiv")
	MenuLabel(AP_MENU_ID_FMT_UNDERLINE,		"&Understreg",		"Understreg den markerede tekst")
	MenuLabel(AP_MENU_ID_FMT_OVERLINE,		"&Overstreg",		"Overstreg den markerede tekst")
	MenuLabel(AP_MENU_ID_FMT_STRIKE,		"&Gennemstreg",		"Gennemstreg den markerede tekst")
	MenuLabel(AP_MENU_ID_FMT_SUPERSCRIPT,		"&Hvet",		"Gr den markerede tekst hjere end omgivelserne")
	MenuLabel(AP_MENU_ID_FMT_SUBSCRIPT,		"S&nket",		"Gr den markerede tekst lavere end omgivelserne")

	MenuLabel(AP_MENU_ID_TOOLS,				"Vr&ktjer",			NULL)   
	MenuLabel(AP_MENU_ID_TOOLS_SPELL,		"&Stavekontrol",	"Kontrollr dokumentet for forkert stavede ord")
	MenuLabel(AP_MENU_ID_TOOLS_WORDCOUNT,	"O&rdoptlling",		"Optl antallet af ord i dokumentet")
	MenuLabel(AP_MENU_ID_TOOLS_OPTIONS,		"&Opstning",			"Opst programmet...")

	MenuLabel(AP_MENU_ID_ALIGN,				"&Justering",			NULL)
	MenuLabel(AP_MENU_ID_ALIGN_LEFT,		"&Venstrestillet",		"Venstrestil afsnittet")
	MenuLabel(AP_MENU_ID_ALIGN_CENTER,		"&Centreret",			"Centrr afsnittet")
	MenuLabel(AP_MENU_ID_ALIGN_RIGHT,		"&Hjrestillet",		"Hjrestil afsnittet")
	MenuLabel(AP_MENU_ID_ALIGN_JUSTIFY,		"&Lige marginer",		"Lav lige marginer p afsnittet")

	MenuLabel(AP_MENU_ID_WINDOW,				"Vi&ndue",			NULL)
	MenuLabel(AP_MENU_ID_WINDOW_NEW,		"&Nyt vindue",			"bn et nyt vindue for dokumentet")
	MenuLabel(AP_MENU_ID_WINDOW_1,			"&1 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_2,			"&2 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_3,			"&3 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_4,			"&4 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_5,			"&5 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_6,			"&6 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_7,			"&7 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_8,			"&8 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_9,			"&9 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_MORE,		"&Flere vinduer",		"Vis en komplet liste over vinduer")

	MenuLabel(AP_MENU_ID_HELP,				"&Hjlp",			NULL)
	MenuLabel(AP_MENU_ID_HELP_ABOUT,		"&Om %s",			"Vis programinformation, versionsnummer og ophavsret")

	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_1,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_2,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_3,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_4,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_5,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_6,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_7,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_8,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_9,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_IGNOREALL,	"&Ignorr alle", 		"Ignorr alle forekomster af dette ord i dokumentet")
	MenuLabel(AP_MENU_ID_SPELL_ADD,			"&Tilfj", 			"Tilfj dette ord til din personlige ordliste")

	// ... add others here ...

	MenuLabel(AP_MENU_ID__BOGUS2__,			NULL,				NULL)

EndSet()

==> abi-0.7.12.tar.gz: abi-0.7.12/src/wp/ap/xp/ap_Menu_LabelSet_da-DK.h <==
/* AbiWord
 * Copyright (C) 1998-2000 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

// Danish translations provided by Martin Willemoes Hansen <mwh@stampede.org>
//                             , Birger Langkjer <birger.langkjer@image.dk>
//                             and Rasmus Toftdahl Olesen <rto@post.tele.dk>

/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

// We use the Win32 '&' character to denote a keyboard accelerator on a menu item.
// If your platform doesn't have a way to do accelerators or uses a different
// character, remove or change the '&' in your menu constructor code.

// If the third argument is UT_TRUE, then this is the fall-back for
// this language (named in the first argument).

BeginSet(da,DK,UT_TRUE)

	MenuLabel(AP_MENU_ID__BOGUS1__,			NULL,				NULL)

	//       (id,                       	szLabel,           	szStatusMsg)

	MenuLabel(AP_MENU_ID_FILE,				"&Filer",			NULL)
	MenuLabel(AP_MENU_ID_FILE_NEW,			"&Ny", 				"Nyt dokument")	
	MenuLabel(AP_MENU_ID_FILE_OPEN,			"&bn",				"bn et eksisterende dokument")
	MenuLabel(AP_MENU_ID_FILE_CLOSE,		"&Luk", 			"Luk dokumentet")
	MenuLabel(AP_MENU_ID_FILE_SAVE,			"&Gem", 			"Gem dokumentet")
	MenuLabel(AP_MENU_ID_FILE_SAVEAS,		"Gem &som", 			"Gem dokumentet under et andet navn")
	MenuLabel(AP_MENU_ID_FILE_PAGESETUP,		"&Sideopstning",		"ndr sideopstning")
	MenuLabel(AP_MENU_ID_FILE_PRINT,		"&Udskriv",			"Udskriv hele dokumentet")
	MenuLabel(AP_MENU_ID_FILE_RECENT_1,		"&1 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_2,		"&2 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_3,		"&3 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_4,		"&4 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_5,		"&5 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_6,		"&6 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_7,		"&7 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_8,		"&8 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_RECENT_9,		"&9 %s",			"bn dette dokument")
	MenuLabel(AP_MENU_ID_FILE_EXIT,			"&Afslut", 			"Luk alle vinduer og afslut programmet")

	MenuLabel(AP_MENU_ID_EDIT,				"&Redigr",			NULL)
	MenuLabel(AP_MENU_ID_EDIT_UNDO,			"F&ortryd",			"Fortryd ndring")
	MenuLabel(AP_MENU_ID_EDIT_REDO,			"&Gentag",			"Gentag sidste fortrydte ndring")
	MenuLabel(AP_MENU_ID_EDIT_CUT,			"K&lip",			"Udklip det markerede og put det i udklipsholderen")
    MenuLabel(AP_MENU_ID_EDIT_COPY,			"&Kopir",			"Kopir det markerede og put det i udklipsholderen")
	MenuLabel(AP_MENU_ID_EDIT_PASTE,		"&Indst",			"Indst udklipsholderens indhold")
	MenuLabel(AP_MENU_ID_EDIT_CLEAR,		"&Ryd",				"Fjern det markerede")
	MenuLabel(AP_MENU_ID_EDIT_SELECTALL,		"&Markr alt",		"Markr hele dokumentet")
	MenuLabel(AP_MENU_ID_EDIT_FIND,			"&Sg",				"Sg efter en angivet tekst")
	MenuLabel(AP_MENU_ID_EDIT_REPLACE,		"&Erstat",			"Erstat en angivet tekst med en anden tekst")
	MenuLabel(AP_MENU_ID_EDIT_GOTO,			"G &til",			"Flyt markren til en angivet placering")
	
	MenuLabel(AP_MENU_ID_VIEW,				"&Vis",				NULL)
	MenuLabel(AP_MENU_ID_VIEW_TOOLBARS,		"&Vrktjslinier",				NULL)
	MenuLabel(AP_MENU_ID_VIEW_TB_STD,		"&Standard",			"Vis eller skjul standard vrktjslinjen")
	MenuLabel(AP_MENU_ID_VIEW_TB_FORMAT,		"&Formatering",			"Vis eller skjul formateringsvrktjslinjen")
	MenuLabel(AP_MENU_ID_VIEW_TB_EXTRA,		"&Ekstra",			"Vis eller skjul den ekstra vrktjslinje")
	MenuLabel(AP_MENU_ID_VIEW_RULER,		"&Lineal",			"Vis eller skjul linealerne")
	MenuLabel(AP_MENU_ID_VIEW_STATUSBAR,		"S&tatuslinie",			"Vis eller skjul statuslinjen")
	MenuLabel(AP_MENU_ID_VIEW_SHOWPARA,		"Vis &afsnit",		"Vis tegn der ikke skal udskrives")
	MenuLabel(AP_MENU_ID_VIEW_HEADFOOT,		"Side&hoved og sidefod",	"Redigr tekst i toppen eller i bunden af hver side")
	MenuLabel(AP_MENU_ID_VIEW_ZOOM,			"&Zoom",			"Formindsk eller forstr dokumentet p skrmen")

	MenuLabel(AP_MENU_ID_INSERT,				"&Indst",			NULL)
	MenuLabel(AP_MENU_ID_INSERT_BREAK,		"&Skift",			"Indst et side-, rkke- eller sektionsskift")
	MenuLabel(AP_MENU_ID_INSERT_PAGENO,		"Side&tal",			"Indst et automatisk opdateret sidetal")
	MenuLabel(AP_MENU_ID_INSERT_DATETIME,		"&Dato og klokkeslet",		"Indst datoen og/eller klokkeslt")
	MenuLabel(AP_MENU_ID_INSERT_FIELD,		"&Felt",			"Indst et kalkuleret felt")
	MenuLabel(AP_MENU_ID_INSERT_SYMBOL,		"Sy&mbol",			"Indst et symbol eller andre specielle tegn")
	MenuLabel(AP_MENU_ID_INSERT_GRAPHIC,		"&Billede",			"Indst et billede fra en fil")

	MenuLabel(AP_MENU_ID_FORMAT,				"F&ormatr",			NULL)
	MenuLabel(AP_MENU_ID_FMT_FONT,			"&Skrifttype",			"ndr skrifttype for den markerede tekst")
	MenuLabel(AP_MENU_ID_FMT_PARAGRAPH,		"&Afsnit",			"ndr formatet for det markerede afsnit")
	MenuLabel(AP_MENU_ID_FMT_BULLETS,		"&Punktopstilling",		"Tilfj eller ndr punktopstillingen i det markerede afsnit")
	MenuLabel(AP_MENU_ID_FMT_BORDERS,		"&Rammer og skygge",		"Tilfj rammer og skygge til den markerede tekst")
	MenuLabel(AP_MENU_ID_FMT_COLUMNS,		"Ko&lonner",			"ndr antallet af kolonner")
	MenuLabel(AP_MENU_ID_FMT_STYLE,			"St&il",			"Angiv eller tilfj stil for den markerede tekst")
	MenuLabel(AP_MENU_ID_FMT_TABS,			"&Tabulatorer",			"St tabulatorstop")
	MenuLabel(AP_MENU_ID_FMT_BOLD,			"&Fed",				"Gr den markerede tekst fed")
	MenuLabel(AP_MENU_ID_FMT_ITALIC,		"&Kursiv",			"Gr den markerede tekst kursiv")
	MenuLabel(AP_MENU_ID_FMT_UNDERLINE,		"&Understreg",		"Understreg den markerede tekst")
	MenuLabel(AP_MENU_ID_FMT_OVERLINE,		"&Overstreg",		"Overstreg den markerede tekst")
	MenuLabel(AP_MENU_ID_FMT_STRIKE,		"&Gennemstreg",		"Gennemstreg den markerede tekst")
	MenuLabel(AP_MENU_ID_FMT_SUPERSCRIPT,		"&Hvet",		"Gr den markerede tekst hjere end omgivelserne")
	MenuLabel(AP_MENU_ID_FMT_SUBSCRIPT,		"S&nket",		"Gr den markerede tekst lavere end omgivelserne")

	MenuLabel(AP_MENU_ID_TOOLS,				"Vr&ktjer",			NULL)   
	MenuLabel(AP_MENU_ID_TOOLS_SPELL,		"&Stavekontrol",	"Kontrollr dokumentet for forkert stavede ord")
	MenuLabel(AP_MENU_ID_TOOLS_WORDCOUNT,	"O&rdoptlling",		"Optl antallet af ord i dokumentet")
	MenuLabel(AP_MENU_ID_TOOLS_OPTIONS,		"&Opstning",			"Opst programmet...")

	MenuLabel(AP_MENU_ID_ALIGN,				"&Justering",			NULL)
	MenuLabel(AP_MENU_ID_ALIGN_LEFT,		"&Venstrestillet",		"Venstrestil afsnittet")
	MenuLabel(AP_MENU_ID_ALIGN_CENTER,		"&Centreret",			"Centrr afsnittet")
	MenuLabel(AP_MENU_ID_ALIGN_RIGHT,		"&Hjrestillet",		"Hjrestil afsnittet")
	MenuLabel(AP_MENU_ID_ALIGN_JUSTIFY,		"&Lige marginer",		"Lav lige marginer p afsnittet")

	MenuLabel(AP_MENU_ID_WINDOW,				"Vi&ndue",			NULL)
	MenuLabel(AP_MENU_ID_WINDOW_NEW,		"&Nyt vindue",			"bn et nyt vindue for dokumentet")
	MenuLabel(AP_MENU_ID_WINDOW_1,			"&1 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_2,			"&2 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_3,			"&3 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_4,			"&4 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_5,			"&5 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_6,			"&6 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_7,			"&7 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_8,			"&8 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_9,			"&9 %s",			"Hent dette vindue")
	MenuLabel(AP_MENU_ID_WINDOW_MORE,		"&Flere vinduer",		"Vis en komplet liste over vinduer")

	MenuLabel(AP_MENU_ID_HELP,				"&Hjlp",		NULL)
	MenuLabel(AP_MENU_ID_HELP_CONTENTS,		"&Indhold af hjlp",	"Vis indhold af hjlp")
	MenuLabel(AP_MENU_ID_HELP_INDEX,		"Hjlpe&indeks",		"Vis hjlpeindeks")
	MenuLabel(AP_MENU_ID_HELP_CHECKVER,		"Tjek &version",	"Vis programversionsnummer")
	MenuLabel(AP_MENU_ID_HELP_SEARCH,		"&Sg i hjlp",	"Vis programinformation, versionsnummer og ophavsret")
	MenuLabel(AP_MENU_ID_HELP_ABOUT,		"&Om %s",			"Vis programinformation, versionsnummer og ophavsret") 
	MenuLabel(AP_MENU_ID_HELP_ABOUTOS,		"Om &Open Source",	"Vis information om Open Source")


	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_1,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_2,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_3,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_4,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_5,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_6,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_7,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_8,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_9,	"%s",				"ndr til det foreslede ord")
	MenuLabel(AP_MENU_ID_SPELL_IGNOREALL,	"&Ignorr alle", 		"Ignorr alle forekomster af dette ord i dokumentet")
	MenuLabel(AP_MENU_ID_SPELL_ADD,			"&Tilfj", 			"Tilfj dette ord til din personlige ordliste")

	// ... add others here ...

	MenuLabel(AP_MENU_ID__BOGUS2__,			NULL,				NULL)

EndSet()
